@@ -6,7 +6,7 @@
 #' 
 #' 
 #' @param subtype A chosen subtype (character)
-#' @param files A named vector. The names of the vector correspond to the
+#' @param files A named vector or list. The names of the vector correspond to the
 #' allowed subtypes and the content of the vector are the corresponding file
 #' names.
 #' @return The file name corresponding to the given subtype
@@ -23,5 +23,5 @@
 toolSubtypeSelect <- function(subtype, files) {
     if(is.null(subtype)) stop('Subtype has to be set! Available subtypes are: ',paste(names(files),collapse=", "))
     if(!(subtype %in% names(files))) stop('Unknown subtype "',subtype,'"! Available subtypes are: ',paste(names(files),collapse=", "))
-    return(files[subtype])
+    return(files[[subtype]])
 } 
